searchData={"items":[{"type":"module","title":"CliexMap","doc":"It is a Unix filter `cliex_map` that applies a pattern to each input line.\nThis is an oppinionated subset of sed with many built in features trimmed for\nfile manipulation (move, rename, format, timestamps) field and substring\nextraction à la `awk` but much more concise and less powerful.\n\nThe design goal is to have a powerful minilanguage to describe patterns in one line mostly.\nWe shall see where this journey shall lead ?)\n\nLet us document how these patterns are compiled, and how the compiled form is rendered.\nHere is a pimitive example which demonstrates this:\n\n    iex(1)> run(~w[1 2], \"Hello\")\n    [\"Hello\", \"Hello\"]\n\nAs a pattern always starts with `%`we can render literal `%`s by doubling them\n\n    iex(2)> run(~w[alpha], \"%% %%\")\n    [\"% %\"]\n\n**N.B.** that end of lines are added if not present","ref":"CliexMap.html"},{"type":"module","title":"Patterns - CliexMap","doc":"The patterns shown above are literals and represented as binaries in the compiled `ast`\n\n#","ref":"CliexMap.html#module-patterns"},{"type":"module","title":"Fields: `%` and `% ` - CliexMap","doc":"The first pattern we are describing here is also the most used it corresponds to _awk's_ `$0`, `$1` and so forth\nbut there is a little bit more here.\n\n  1. Instead of `$` we use `%` (for simpler shell integration, inspored by _xargs_)\n  1. We can write `%` as shortcut for `%0` and we can write `%-1`, for _awk's_  `$NF`\n     `%-2` for `$(NF-1)` and so on\n\n  1. We can substring, format and modify `%f ` as all other patterns, which will show in the corresponding sections\n\nHere is a simple echo pattern with and without the explicit `0`\n\n    iex(3)> run(~w[alpha beta], \"%\")\n    ~w[alpha beta]\n\n**N.B.** that `M` is a shortcut for `CliexMap.Modifiers` defined in the doctest for readability\n\nAnd here the (double) echo with an explicit 0\n\n    iex(4)> run(~w[alpha], \"% %0\")\n    [\"alpha alpha\"]\n\nIf there is only one field than `%1` is, _again_, the synonyme of `%`\n\n    iex(5)> run([\"alpha\", \"beta gamma\"], \"% %1\")\n    [\"alpha alpha\", \"beta gamma beta\"]\n\nNow let us show how negative indices and indices of non existing fields are rendered\n\n    iex(6)> sentence = \"The quick brown fox jumps\"\n    ...(6)> run([sentence], \"%-1 %-2 '%6'\")\n    [\"jumps fox ''\"]\n\n#","ref":"CliexMap.html#module-fields-and"},{"type":"module","title":"Line Numbers: `%n` - CliexMap","doc":"This is rendered like _awk's_ `$NR - 1`\n\n    iex(7)> run([\"\", \"\", \"ignored\"], \"%n\")\n    ~w[0 1 2]\n\n\n#","ref":"CliexMap.html#module-line-numbers-n"},{"type":"module","title":"Timestamps: `%ts`, `%tms`, `%tmics`, \"%xs\", `%xms` and `%xmics` - CliexMap","doc":"These fields are rendererd with the unix timestamp in seconds, milliseconds or microseconds with the **same** timestamp for all\ninput lines, tusly mapping it for each line to a constant value.\n\n    iex(8)> run([\"\"], \"%ts\", C.for_now(1691231907123456))\n    [\"1691231907\"]\n\n**N.B.** that `C` is a shortcut for `CliexMap.Context` defined in the doctest for readability\nand the context will be generated when the pattern is compiled. As a consequence `%ts` and\nfriends will all be rendered itentically for each input line, here are examples for the other\n5 timestamp formats.\n\n    iex(9)> run([\"\"], \"%tms\", C.for_now(1691231907123456))\n    [\"1691231907123\"]\n\n    iex(10)> run([\"\", \"\", \"\"], \"%tmics\", C.for_now(1691231907123456))\n    [\"1691231907123456\", \"1691231907123456\", \"1691231907123456\"]\n\n    iex(11)> run([\"\"], \"%xs\", C.for_now(1691231907123456))\n    [\"64ce26a3\"]\n\n    iex(12)> run([\"\"], \"%xms\", C.for_now(1691231907123456))\n    [\"189c546ed33\"]\n\n    iex(13)> run([\"\", \"\", \"\"], \"%xmics\", C.for_now(1691231907123456))\n    [\"6022a9d0e9100\", \"6022a9d0e9100\", \"6022a9d0e9100\"]\n\n#","ref":"CliexMap.html#module-timestamps-ts-tms-tmics-xs-xms-and-xmics"},{"type":"module","title":"Variables - CliexMap","doc":"While, up to here, patterns have been simple we will see later that they can become quite complicated.\nWithout explaining the details of the following examples we will see that we need to rewrite a long\npattern to create the desired command for each input line\n\n    iex(14)> run([\"src/DIR/subdir/file.jsno\"],\n    ...(14)> ~s{mkdir -p bup/%xs/%(segments 1 -2)(downcase); cp % bup/%xs/%(segments 1 -2)(downcase)/%(segments -1)(sub \".jsno\" \".json\")},\n    ...(14)> C.for_now(1691231907123456))\n    [\"mkdir -p bup/64ce26a3/dir/subdir; cp src/DIR/subdir/file.jsno bup/64ce26a3/dir/subdir/file.json\"]\n\nActually the patterns above are a little bit more complicated as needed but this is to demonstrate the usage of Variables\n\n##","ref":"CliexMap.html#module-variables"},{"type":"module","title":"Setting a variable with `%S` - CliexMap","doc":"The `%S  ` will compile ` ` but instead of rendering its result it will store it in the context, thusly the\nfollowing is useless\n\n    iex(15)> run([\"useless input\"], \"%Saa<%(split)(revlist)(join)>\")\n    [\"\"]\n\nWe can, however use the variable **after** its declaration, and that, many times\n\n    iex(16)> run([\"A B\"], \"%Sx<%(downcase)(split)(revlist)(join)>-%Lx-%Lx-%Lx-\")\n    [\"-ba-ba-ba-\"]\n\nOf course a loaded variable can be modified as every other field\n\n    iex(17)> run([\"A B\"], \"%Sx<%(downcase)(split)(revlist)(join)>-%Lx-%Lx(upcase)\")\n    [\"-ba-BA\"]\n\nVariables can also be used to store constant strings\n\n    iex(18)> run([\"\"], \"%Sworld %Lworld %Lworld(split)(at 1)\")\n    [\"Brave new world new\"]","ref":"CliexMap.html#module-setting-a-variable-with-s"},{"type":"module","title":"Pattern Modifiers - CliexMap","doc":"All patterns can be modified by a little, lisp like minilanguage directly attached to the pattern.\nThis LLLML is expressed in form of s-expressions with built in predefined functions.\n\nThe value of the field is injected into the first such s-expression, the result of which is\ninjected into the second s-expression and so forth, here are some examples to demonstrate the\nprinciple\n\n      iex(19)> run([\"alpha\"], \"%(reverse)\")\n      [\"ahpla\"]\n\nBelow we will list all available built in functions, but here we will also show the more common use\ncases like splitting, extracting and combining segments of strings, formatting output and the shortcut\nsyntax that allows us to write common used modifiers in an even shorter form than LLLML\n\n#","ref":"CliexMap.html#module-pattern-modifiers"},{"type":"module","title":"Counting Modifiers and their shortcuts - CliexMap","doc":"Let us imagien that we want to preceede line numbers by their tenfolds and want to start with 10, what\nwe can do of course is to use LLLML as follows\n\n    iex(20)> run([\"a\", \"a\", \"a\", \"a\"], \"%n(+ 1)(* 10) %\")\n    [\"10 a\", \"20 a\", \"30 a\", \"40 a\"]\n\nThere are cases where we need the injected line number to be the second argument of a function, e.g.\nif we want to count down. We can indicate the position where a value shall be injected by the placeholder  `_`\n\n    iex(21)> run([\"b\", \"b\", \"b\"], \"%n(* -10)(+ 110) %\")\n    [\"110 b\", \"100 b\", \"90 b\"]\n\n\nThis is obviously a handful, and therefore we provide a shortcut with a simple value notation\n\n    iex(22)> run([\"b\", \"b\", \"b\"], \"%n:110,-10: %\")\n    [\"110 b\", \"100 b\", \"90 b\"]\n\nAnd the one value version can be used to change the start count, 1 being a popular choice ;)\n\n    iex(23)> run([\"b\", \"b\", \"e\"], \"%n:1: %\")\n    [\"1 b\", \"2 b\", \"3 e\"]\n\n#","ref":"CliexMap.html#module-counting-modifiers-and-their-shortcuts"},{"type":"module","title":"Formatting Modifiers and their shortcuts - CliexMap","doc":"When inserting strings or numbers into the output we oftentimes need to align them to a length, we also sometimes\nwant to pad them with spaces, zeroes or different characters. This all, of course, can be done with LLLML but\nas we will show here, shorter patterns are desired and therefore implemented.\n\n##","ref":"CliexMap.html#module-formatting-modifiers-and-their-shortcuts"},{"type":"module","title":"Aligning strings and numbers - CliexMap","doc":"iex(24)> run(~w[alpha beta], \"%(rpad 6)\")\n    [\"alpha \", \"beta  \"]\n\n  And the shorter\n\n    iex(25)> run(~w[alpha beta], \"%<-6>\")\n    [\"alpha \", \"beta  \"]\n\n  Or\n\n    iex(26)> run(~w[alpha beta], \"%(lpad 6 -)\")\n    [\"-alpha\", \"--beta\"]\n\n  And the shorter\n\n    iex(27)> run(~w[alpha beta], \"%<6->\")\n    [\"-alpha\", \"--beta\"]\n\n\n    iex(28)> run([\"\", \"\"], \"%n<2 0>\")  # Note the space in order to avoid a length of 20\n    [\"00\", \"01\"]\n\n##","ref":"CliexMap.html#module-aligning-strings-and-numbers"},{"type":"module","title":"Formatting Numbers - CliexMap","doc":"iex(29)> run([\"\", \"\"], \"%n:15:(to_s 16)(lpad 2 0)\")\n    [\"0f\", \"10\"]\n\n  And the shorter\n\n    iex(30)> run([\"\", \"\"], \"%n:15:<2x0>\")\n    [\"0f\", \"10\"]\n\n\n\n#","ref":"CliexMap.html#module-formatting-numbers"},{"type":"module","title":"Parameter Positions - CliexMap","doc":"Oftentimes we will use the result of a field as the first argument in a modifier, however, sometimes we would\nneed to inject it at a different position.\n\nWe can use the placeholde `_` for this.\n\nWe can demonstrate with an explicit implementation of counting down line numbers (which of course is done with the\nshortcuts shown above\n\n    iex(31)> run([\"\", \"\", \"\"], \"%n(- 10 _)\")\n    [\"10\", \"9\", \"8\"]","ref":"CliexMap.html#module-parameter-positions"},{"type":"module","title":"Cookbooks - CliexMap","doc":"#","ref":"CliexMap.html#module-cookbooks"},{"type":"module","title":"File Trees - CliexMap","doc":"##","ref":"CliexMap.html#module-file-trees"},{"type":"module","title":"Duplicate a directory structure - CliexMap","doc":"We have a structure like that\n\n      src\n        |\n        + namespace_1\n        |  |\n        |  +---- file1.json, ...., filen.json\n        |\n        + namespace_2\n        |  |\n        |  +---- file1.json, ...., filen.json\n        |\n        + namespace_3\n           |\n           +---- file1.json, ...., filen.json\n\nAnd want to create a structure like that\n\n\n\n     tests\n       |\n       json_tests\n         |\n         + namespace_1\n         |  |\n         |  +---- file1_test.exs, ...., filen_test.exs\n         |\n         + namespace_2\n         |  |\n         |  +---- file1_test.exs, ...., filen_test.exs\n         |\n         + namespace_3\n           |\n           +---- file1_test.exs, ...., filen_test.exs\n\nBy using the output from, e.g. `git ls-files src` or `find src -name '*.json'` we can map the input with the following pattern\n\n      iex(32)> input = ~W[ src/namespace_1/file1.json src/namespace_2/file1.json src/namespace_2/file2.json ]\n      ...(32)> run(input, \"mkdir -p tests/json_tests/%(segment 1); touch tests/json_tests/%(segments 1 2)(sub '.json' '_test.exs')\")\n      [\n        \"mkdir -p tests/json_tests/namespace_1; touch tests/json_tests/namespace_1/file1_test.exs\",\n        \"mkdir -p tests/json_tests/namespace_2; touch tests/json_tests/namespace_2/file1_test.exs\",\n        \"mkdir -p tests/json_tests/namespace_2; touch tests/json_tests/namespace_2/file2_test.exs\"\n      ]\n\nChanging and using extensions of filenames is frequent enough to justify the `ext` builtin\n\n      iex(33)> input = ~W[ src/namespace_1/file1.json ]\n      ...(33)> run(input, \"mkdir -p tests/json_tests/%(segment 1); touch tests/json_tests/%(segments 1 2)(ext _test.exs)\")\n      [\n        \"mkdir -p tests/json_tests/namespace_1; touch tests/json_tests/namespace_1/file1_test.exs\",\n      ]","ref":"CliexMap.html#module-duplicate-a-directory-structure"},{"type":"module","title":"Comprehensive List of Builtin Functions - CliexMap","doc":"We use `B` as a shortcut to `CliexMap.Builtins`, we also pass in a `CliexMap.Context` (aliased to `C`)\n  only if needed\n\n#","ref":"CliexMap.html#module-comprehensive-list-of-builtin-functions"},{"type":"module","title":"abs - CliexMap","doc":"iex(34)> B.abs(nil, [-10])\n    10\n\n#","ref":"CliexMap.html#module-abs"},{"type":"module","title":"add (used for `+`) - CliexMap","doc":"iex(35)> B._add(nil, [1, 2, 3, 4])\n    10\n\n#","ref":"CliexMap.html#module-add-used-for"},{"type":"module","title":"at (alias to Enum.at) - CliexMap","doc":"iex(36)> B.at(nil, [~w[a b c], 2])\n    \"c\"\n\n    iex(37)> B.at(nil, [~w[a b c], -3])\n    \"a\"\n\n    iex(38)> B.at(nil, [~w[a b c], 1, :default])\n    \"b\"\n\n    iex(39)> B.at(nil, [~w[a b c], 3, :default])\n    :default \n\n#","ref":"CliexMap.html#module-at-alias-to-enum-at"},{"type":"module","title":"div (used for `/`) - CliexMap","doc":"iex(40)> B._div(nil, [9, 4])\n    2.25\n\n#","ref":"CliexMap.html#module-div-used-for"},{"type":"module","title":"downcase - CliexMap","doc":"iex(41)> B.downcase(nil, [\"HELLO\"])\n    \"hello\"\n\n#","ref":"CliexMap.html#module-downcase"},{"type":"module","title":"ext/1 - CliexMap","doc":"Returns last extension of a filename\n\n    iex(42)> B.ext(nil, [\"a.html.eex\"])\n    \"eex\"\n\n  If no extension is found it returns an empty string\n\n    iex(43)> B.ext(nil, [\"a\"])\n    \"\"\n\n#","ref":"CliexMap.html#module-ext-1"},{"type":"module","title":"ext/2 - CliexMap","doc":"Changes last extension of a filename, **N.B.** that the `.` is not added automatically\n    iex(44)> B.ext(nil, [\"a.html.erb\", \".eex\"])\n    \"a.html.eex\"\n\n#","ref":"CliexMap.html#module-ext-2"},{"type":"module","title":"idiv (used for `:`) - CliexMap","doc":"iex(45)> B._idiv(nil, [9, 4])\n    2\n\n#","ref":"CliexMap.html#module-idiv-used-for"},{"type":"module","title":"join - CliexMap","doc":"iex(46)> B.join(nil, [[1, 2]])\n    \"12\"\n\n    iex(47)> B.join(nil, [[1, 2, 3], \" \"])\n    \"1 2 3\"\n\n#","ref":"CliexMap.html#module-join"},{"type":"module","title":"lpad - CliexMap","doc":"iex(48)> B.lpad(nil, [\"a\", 2])\n  \" a\"\n\n  iex(49)> B.lpad(nil, [\"a\", 3, :\"-*\"])\n  \"-*a\"\n\n#","ref":"CliexMap.html#module-lpad"},{"type":"module","title":"mul - CliexMap","doc":"iex(50)> B._mul(nil, [1, 2, 3, 4])\n    24\n\n#","ref":"CliexMap.html#module-mul"},{"type":"module","title":"reverse - CliexMap","doc":"iex(51)> B.reverse(nil, [\"alpha\"])\n    \"ahpla\"\n\n#","ref":"CliexMap.html#module-reverse"},{"type":"module","title":"revlist - CliexMap","doc":"iex(52)> B.revlist(nil, [~W[a b]])\n    ~W[b a]\n\n#","ref":"CliexMap.html#module-revlist"},{"type":"module","title":"rpad - CliexMap","doc":"iex(53)> B.rpad(nil, [\"a\", 2])\n  \"a \"\n\n  iex(54)> B.rpad(nil, [\"a\", 3, :\"--\"])\n  \"a--\"\n\n#","ref":"CliexMap.html#module-rpad"},{"type":"module","title":"segment Extract a path - CliexMap","doc":"- with -1 like `basename`\n    iex(55)> B.segment(nil, [\"a/b/c\", -1])\n    \"c\"\n\n- without an arg like `dirname`\n    iex(56)> B.segment(nil, [\"a/b/c\"])\n    \"a/b\"\n\n- or any part\n\n    iex(57)> B.segment(nil, [\"a/b/c\", 0])\n    \"a\"\n\n    iex(58)> B.segment(nil, [\"a/b/c\", -2])\n    \"b\"\n\n\n#","ref":"CliexMap.html#module-segment-extract-a-path"},{"type":"module","title":"segments (short for `(splicej  \"/\" _1 _2)`) - CliexMap","doc":"iex(59)> B.segments(nil, [\"x/y/z\", 2])\n    \"z\"\n\n    iex(60)> B.segments(nil, [\"x/y/z\", -2, -1])\n    \"y/z\"\n\n#","ref":"CliexMap.html#module-segments-short-for-splicej-_1-_2"},{"type":"module","title":"slice - CliexMap","doc":"##","ref":"CliexMap.html#module-slice"},{"type":"module","title":"lists - CliexMap","doc":"iex(61)> B.slice(nil, [~w[a b c d], 1])\n    ~w[b c d]\n\n    iex(62)> B.slice(nil, [~w[a b c d], 2, 3])\n    ~w[c d]\n\n    iex(63)> B.slice(nil, [~w[a b c d], -2])\n    ~w[c d]\n\n    iex(64)> B.slice(nil, [~w[a b c d], -4, -2])\n    ~w[a b c]\n\n    iex(65)> B.slice(nil, [~w[a b c d], -4, 1])\n    ~w[a b]\n\n    iex(66)> B.slice(nil, [~w[a b c d], 1, 0])\n    []\n\n##","ref":"CliexMap.html#module-lists"},{"type":"module","title":"strings - CliexMap","doc":"iex(67)> B.slice(nil, [\"abc\", 1])\n    \"bc\"\n\n    iex(68)> B.slice(nil, [\"abc\", -1])\n    \"c\"\n\n    iex(69)> B.slice(nil, [\"abc\", 1, 2])\n    \"bc\"\n\n    iex(70)> B.slice(nil, [\"abcd\", -2, -1])\n    \"cd\"\n\n    iex(71)> B.slice(nil, [\"abcd\", -2, 3])\n    \"cd\"\n\n    iex(72)> B.slice(nil, [\"abc\", 0, -2])\n    \"ab\"\n\n#","ref":"CliexMap.html#module-strings"},{"type":"module","title":"splicej (or splice_join) split, splice and join - CliexMap","doc":"- join on original seperator\n\n        iex(73)> B.splicej(nil, [\"a/b/c/d/e\", \"/\", 2, 3])\n        \"c/d\"\n\n  - join on original seperator, slice to the end\n\n        iex(74)> B.splicej(nil, [\"a/b/c/d/e\", \"/\", 2])\n        \"c/d/e\"\n\n  - join with different string\n\n        iex(75)> B.splice_join(nil, [\"a/b/c/d/e\", \"/\", 2, 3, \",\"])\n        \"c,d\"\n\n#","ref":"CliexMap.html#module-splicej-or-splice_join-split-splice-and-join"},{"type":"module","title":"split - CliexMap","doc":"iex(76)> B.split(nil, [\"a b\"])\n    [\"a\", \"b\"]\n\n    iex(77)> B.split(nil, [\"a,b\", \",\"])\n    [\"a\", \"b\"]\n\n#","ref":"CliexMap.html#module-split"},{"type":"module","title":"sub (from `-`) (use with care) - CliexMap","doc":"iex(78)> B._sub(nil, [1, 2, 3, 4])\n    -8\n\n#","ref":"CliexMap.html#module-sub-from-use-with-care"},{"type":"module","title":"sub (from `sub`) - CliexMap","doc":"iex(79)> B.sub(nil, [\"Hello World\", \"l\"])\n    \"Heo Word\"\n\n    iex(80)> B.sub(nil, [\"Hello World\", \"l\", \"L\"])\n    \"HeLLo WorLd\"\n\n#","ref":"CliexMap.html#module-sub-from-sub"},{"type":"module","title":"to_s (for numbers only) - CliexMap","doc":"iex(81)> B.to_s(nil, [12])\n    \"12\"\n\n    iex(82)> B.to_s(nil, [12, 16])\n    \"c\"\n    \n#","ref":"CliexMap.html#module-to_s-for-numbers-only"},{"type":"module","title":"upcase - CliexMap","doc":"iex(83)> B.upcase(nil, [\"hello\"])\n    \"HELLO\"","ref":"CliexMap.html#module-upcase"},{"type":"function","title":"CliexMap.run/3","doc":"","ref":"CliexMap.html#run/3"},{"type":"module","title":"CliexMap.Builtins","doc":"Built in functions which can be called in pattern modfifers `(reverse)(downcase)`","ref":"CliexMap.Builtins.html"},{"type":"function","title":"CliexMap.Builtins.abs/2","doc":"","ref":"CliexMap.Builtins.html#abs/2"},{"type":"function","title":"CliexMap.Builtins.at/2","doc":"","ref":"CliexMap.Builtins.html#at/2"},{"type":"function","title":"CliexMap.Builtins.downcase/2","doc":"","ref":"CliexMap.Builtins.html#downcase/2"},{"type":"function","title":"CliexMap.Builtins.ext/2","doc":"","ref":"CliexMap.Builtins.html#ext/2"},{"type":"function","title":"CliexMap.Builtins.join/2","doc":"","ref":"CliexMap.Builtins.html#join/2"},{"type":"function","title":"CliexMap.Builtins.lpad/2","doc":"","ref":"CliexMap.Builtins.html#lpad/2"},{"type":"function","title":"CliexMap.Builtins.map_either/2","doc":"","ref":"CliexMap.Builtins.html#map_either/2"},{"type":"function","title":"CliexMap.Builtins.reverse/2","doc":"","ref":"CliexMap.Builtins.html#reverse/2"},{"type":"function","title":"CliexMap.Builtins.revlist/2","doc":"","ref":"CliexMap.Builtins.html#revlist/2"},{"type":"function","title":"CliexMap.Builtins.rnd/2","doc":"","ref":"CliexMap.Builtins.html#rnd/2"},{"type":"function","title":"CliexMap.Builtins.rpad/2","doc":"","ref":"CliexMap.Builtins.html#rpad/2"},{"type":"function","title":"CliexMap.Builtins.segment/2","doc":"","ref":"CliexMap.Builtins.html#segment/2"},{"type":"function","title":"CliexMap.Builtins.segments/2","doc":"","ref":"CliexMap.Builtins.html#segments/2"},{"type":"function","title":"CliexMap.Builtins.slice/2","doc":"","ref":"CliexMap.Builtins.html#slice/2"},{"type":"function","title":"CliexMap.Builtins.splice_join/2","doc":"","ref":"CliexMap.Builtins.html#splice_join/2"},{"type":"function","title":"CliexMap.Builtins.splicej/2","doc":"","ref":"CliexMap.Builtins.html#splicej/2"},{"type":"function","title":"CliexMap.Builtins.split/2","doc":"","ref":"CliexMap.Builtins.html#split/2"},{"type":"function","title":"CliexMap.Builtins.sub/2","doc":"","ref":"CliexMap.Builtins.html#sub/2"},{"type":"function","title":"CliexMap.Builtins.to_s/2","doc":"","ref":"CliexMap.Builtins.html#to_s/2"},{"type":"function","title":"CliexMap.Builtins.upcase/2","doc":"","ref":"CliexMap.Builtins.html#upcase/2"},{"type":"type","title":"CliexMap.Builtins.ast/0","doc":"","ref":"CliexMap.Builtins.html#t:ast/0"},{"type":"type","title":"CliexMap.Builtins.binaries/0","doc":"","ref":"CliexMap.Builtins.html#t:binaries/0"},{"type":"type","title":"CliexMap.Builtins.binary?/0","doc":"","ref":"CliexMap.Builtins.html#t:binary?/0"},{"type":"type","title":"CliexMap.Builtins.color_list/0","doc":"","ref":"CliexMap.Builtins.html#t:color_list/0"},{"type":"type","title":"CliexMap.Builtins.either/2","doc":"","ref":"CliexMap.Builtins.html#t:either/2"},{"type":"type","title":"CliexMap.Builtins.line_nb_t/0","doc":"","ref":"CliexMap.Builtins.html#t:line_nb_t/0"},{"type":"type","title":"CliexMap.Builtins.maybe/1","doc":"","ref":"CliexMap.Builtins.html#t:maybe/1"},{"type":"type","title":"CliexMap.Builtins.name_value_pair_t/0","doc":"","ref":"CliexMap.Builtins.html#t:name_value_pair_t/0"},{"type":"type","title":"CliexMap.Builtins.numbered_line_t/0","doc":"","ref":"CliexMap.Builtins.html#t:numbered_line_t/0"},{"type":"module","title":"CliexMap.Cli","doc":"The escript main module","ref":"CliexMap.Cli.html"},{"type":"function","title":"CliexMap.Cli.main/1","doc":"","ref":"CliexMap.Cli.html#main/1"},{"type":"function","title":"CliexMap.Cli.main/2","doc":"","ref":"CliexMap.Cli.html#main/2"},{"type":"function","title":"CliexMap.Cli.map_either/2","doc":"","ref":"CliexMap.Cli.html#map_either/2"},{"type":"type","title":"CliexMap.Cli.ast/0","doc":"","ref":"CliexMap.Cli.html#t:ast/0"},{"type":"type","title":"CliexMap.Cli.binaries/0","doc":"","ref":"CliexMap.Cli.html#t:binaries/0"},{"type":"type","title":"CliexMap.Cli.binary?/0","doc":"","ref":"CliexMap.Cli.html#t:binary?/0"},{"type":"type","title":"CliexMap.Cli.color_list/0","doc":"","ref":"CliexMap.Cli.html#t:color_list/0"},{"type":"type","title":"CliexMap.Cli.either/2","doc":"","ref":"CliexMap.Cli.html#t:either/2"},{"type":"type","title":"CliexMap.Cli.line_nb_t/0","doc":"","ref":"CliexMap.Cli.html#t:line_nb_t/0"},{"type":"type","title":"CliexMap.Cli.maybe/1","doc":"","ref":"CliexMap.Cli.html#t:maybe/1"},{"type":"type","title":"CliexMap.Cli.name_value_pair_t/0","doc":"","ref":"CliexMap.Cli.html#t:name_value_pair_t/0"},{"type":"type","title":"CliexMap.Cli.numbered_line_t/0","doc":"","ref":"CliexMap.Cli.html#t:numbered_line_t/0"},{"type":"module","title":"CliexMap.Context","doc":"","ref":"CliexMap.Context.html"},{"type":"function","title":"CliexMap.Context.for_now/1","doc":"","ref":"CliexMap.Context.html#for_now/1"},{"type":"function","title":"CliexMap.Context.format_ts_fn/2","doc":"","ref":"CliexMap.Context.html#format_ts_fn/2"},{"type":"function","title":"CliexMap.Context.load_variable/2","doc":"","ref":"CliexMap.Context.html#load_variable/2"},{"type":"function","title":"CliexMap.Context.map_either/2","doc":"","ref":"CliexMap.Context.html#map_either/2"},{"type":"function","title":"CliexMap.Context.store_variable/2","doc":"","ref":"CliexMap.Context.html#store_variable/2"},{"type":"type","title":"CliexMap.Context.ast/0","doc":"","ref":"CliexMap.Context.html#t:ast/0"},{"type":"type","title":"CliexMap.Context.binaries/0","doc":"","ref":"CliexMap.Context.html#t:binaries/0"},{"type":"type","title":"CliexMap.Context.binary?/0","doc":"","ref":"CliexMap.Context.html#t:binary?/0"},{"type":"type","title":"CliexMap.Context.color_list/0","doc":"","ref":"CliexMap.Context.html#t:color_list/0"},{"type":"type","title":"CliexMap.Context.either/2","doc":"","ref":"CliexMap.Context.html#t:either/2"},{"type":"type","title":"CliexMap.Context.line_nb_t/0","doc":"","ref":"CliexMap.Context.html#t:line_nb_t/0"},{"type":"type","title":"CliexMap.Context.maybe/1","doc":"","ref":"CliexMap.Context.html#t:maybe/1"},{"type":"type","title":"CliexMap.Context.name_value_pair_t/0","doc":"","ref":"CliexMap.Context.html#t:name_value_pair_t/0"},{"type":"type","title":"CliexMap.Context.numbered_line_t/0","doc":"","ref":"CliexMap.Context.html#t:numbered_line_t/0"},{"type":"type","title":"CliexMap.Context.t/0","doc":"","ref":"CliexMap.Context.html#t:t/0"},{"type":"module","title":"CliexMap.Fn","doc":"A simple wrapper around functions for readability","ref":"CliexMap.Fn.html"},{"type":"function","title":"CliexMap.Fn.call/3","doc":"","ref":"CliexMap.Fn.html#call/3"},{"type":"function","title":"CliexMap.Fn.map_either/2","doc":"","ref":"CliexMap.Fn.html#map_either/2"},{"type":"function","title":"CliexMap.Fn.new/2","doc":"","ref":"CliexMap.Fn.html#new/2"},{"type":"type","title":"CliexMap.Fn.ast/0","doc":"","ref":"CliexMap.Fn.html#t:ast/0"},{"type":"type","title":"CliexMap.Fn.binaries/0","doc":"","ref":"CliexMap.Fn.html#t:binaries/0"},{"type":"type","title":"CliexMap.Fn.binary?/0","doc":"","ref":"CliexMap.Fn.html#t:binary?/0"},{"type":"type","title":"CliexMap.Fn.color_list/0","doc":"","ref":"CliexMap.Fn.html#t:color_list/0"},{"type":"type","title":"CliexMap.Fn.either/2","doc":"","ref":"CliexMap.Fn.html#t:either/2"},{"type":"type","title":"CliexMap.Fn.fn_result_t/0","doc":"","ref":"CliexMap.Fn.html#t:fn_result_t/0"},{"type":"type","title":"CliexMap.Fn.fn_t/0","doc":"","ref":"CliexMap.Fn.html#t:fn_t/0"},{"type":"type","title":"CliexMap.Fn.line_nb_t/0","doc":"","ref":"CliexMap.Fn.html#t:line_nb_t/0"},{"type":"type","title":"CliexMap.Fn.maybe/1","doc":"","ref":"CliexMap.Fn.html#t:maybe/1"},{"type":"type","title":"CliexMap.Fn.name_value_pair_t/0","doc":"","ref":"CliexMap.Fn.html#t:name_value_pair_t/0"},{"type":"type","title":"CliexMap.Fn.numbered_line_t/0","doc":"","ref":"CliexMap.Fn.html#t:numbered_line_t/0"},{"type":"type","title":"CliexMap.Fn.t/0","doc":"","ref":"CliexMap.Fn.html#t:t/0"},{"type":"module","title":"CliexMap.FunctionList","doc":"Wraps a  list of functions","ref":"CliexMap.FunctionList.html"},{"type":"function","title":"CliexMap.FunctionList.add_function/2","doc":"","ref":"CliexMap.FunctionList.html#add_function/2"},{"type":"function","title":"CliexMap.FunctionList.add_sexp/2","doc":"","ref":"CliexMap.FunctionList.html#add_sexp/2"},{"type":"function","title":"CliexMap.FunctionList.map_either/2","doc":"","ref":"CliexMap.FunctionList.html#map_either/2"},{"type":"function","title":"CliexMap.FunctionList.new/1","doc":"","ref":"CliexMap.FunctionList.html#new/1"},{"type":"type","title":"CliexMap.FunctionList.ast/0","doc":"","ref":"CliexMap.FunctionList.html#t:ast/0"},{"type":"type","title":"CliexMap.FunctionList.binaries/0","doc":"","ref":"CliexMap.FunctionList.html#t:binaries/0"},{"type":"type","title":"CliexMap.FunctionList.binary?/0","doc":"","ref":"CliexMap.FunctionList.html#t:binary?/0"},{"type":"type","title":"CliexMap.FunctionList.color_list/0","doc":"","ref":"CliexMap.FunctionList.html#t:color_list/0"},{"type":"type","title":"CliexMap.FunctionList.either/2","doc":"","ref":"CliexMap.FunctionList.html#t:either/2"},{"type":"type","title":"CliexMap.FunctionList.line_nb_t/0","doc":"","ref":"CliexMap.FunctionList.html#t:line_nb_t/0"},{"type":"type","title":"CliexMap.FunctionList.maybe/1","doc":"","ref":"CliexMap.FunctionList.html#t:maybe/1"},{"type":"type","title":"CliexMap.FunctionList.name_value_pair_t/0","doc":"","ref":"CliexMap.FunctionList.html#t:name_value_pair_t/0"},{"type":"type","title":"CliexMap.FunctionList.numbered_line_t/0","doc":"","ref":"CliexMap.FunctionList.html#t:numbered_line_t/0"},{"type":"type","title":"CliexMap.FunctionList.t/0","doc":"","ref":"CliexMap.FunctionList.html#t:t/0"},{"type":"module","title":"CliexMap.Mapper","doc":"Maps each line according to pattern to a new, `\\n` terminated string","ref":"CliexMap.Mapper.html"},{"type":"function","title":"CliexMap.Mapper.map/3","doc":"","ref":"CliexMap.Mapper.html#map/3"},{"type":"function","title":"CliexMap.Mapper.map_either/2","doc":"","ref":"CliexMap.Mapper.html#map_either/2"},{"type":"function","title":"CliexMap.Mapper.transform_line/3","doc":"","ref":"CliexMap.Mapper.html#transform_line/3"},{"type":"type","title":"CliexMap.Mapper.ast/0","doc":"","ref":"CliexMap.Mapper.html#t:ast/0"},{"type":"type","title":"CliexMap.Mapper.binaries/0","doc":"","ref":"CliexMap.Mapper.html#t:binaries/0"},{"type":"type","title":"CliexMap.Mapper.binary?/0","doc":"","ref":"CliexMap.Mapper.html#t:binary?/0"},{"type":"type","title":"CliexMap.Mapper.color_list/0","doc":"","ref":"CliexMap.Mapper.html#t:color_list/0"},{"type":"type","title":"CliexMap.Mapper.either/2","doc":"","ref":"CliexMap.Mapper.html#t:either/2"},{"type":"type","title":"CliexMap.Mapper.line_nb_t/0","doc":"","ref":"CliexMap.Mapper.html#t:line_nb_t/0"},{"type":"type","title":"CliexMap.Mapper.maybe/1","doc":"","ref":"CliexMap.Mapper.html#t:maybe/1"},{"type":"type","title":"CliexMap.Mapper.name_value_pair_t/0","doc":"","ref":"CliexMap.Mapper.html#t:name_value_pair_t/0"},{"type":"type","title":"CliexMap.Mapper.numbered_line_t/0","doc":"","ref":"CliexMap.Mapper.html#t:numbered_line_t/0"},{"type":"module","title":"CliexMap.PipelineFunctions","doc":"Implements all functions the compiler compiles to.\nIt is like a runtime, but as we will always use them in the Mapper's pipeline the naming seems\nappropriate","ref":"CliexMap.PipelineFunctions.html"},{"type":"function","title":"CliexMap.PipelineFunctions.field_function/1","doc":"Function that represents fields like `%`, `%2` or `%-3`","ref":"CliexMap.PipelineFunctions.html#field_function/1"},{"type":"function","title":"CliexMap.PipelineFunctions.literal_function/1","doc":"Fucnction that represents literal strings in the pattern, e.g. `%%` or `Hello World`","ref":"CliexMap.PipelineFunctions.html#literal_function/1"},{"type":"function","title":"CliexMap.PipelineFunctions.map_either/2","doc":"","ref":"CliexMap.PipelineFunctions.html#map_either/2"},{"type":"type","title":"CliexMap.PipelineFunctions.ast/0","doc":"","ref":"CliexMap.PipelineFunctions.html#t:ast/0"},{"type":"type","title":"CliexMap.PipelineFunctions.binaries/0","doc":"","ref":"CliexMap.PipelineFunctions.html#t:binaries/0"},{"type":"type","title":"CliexMap.PipelineFunctions.binary?/0","doc":"","ref":"CliexMap.PipelineFunctions.html#t:binary?/0"},{"type":"type","title":"CliexMap.PipelineFunctions.color_list/0","doc":"","ref":"CliexMap.PipelineFunctions.html#t:color_list/0"},{"type":"type","title":"CliexMap.PipelineFunctions.either/2","doc":"","ref":"CliexMap.PipelineFunctions.html#t:either/2"},{"type":"type","title":"CliexMap.PipelineFunctions.line_nb_t/0","doc":"","ref":"CliexMap.PipelineFunctions.html#t:line_nb_t/0"},{"type":"type","title":"CliexMap.PipelineFunctions.maybe/1","doc":"","ref":"CliexMap.PipelineFunctions.html#t:maybe/1"},{"type":"type","title":"CliexMap.PipelineFunctions.name_value_pair_t/0","doc":"","ref":"CliexMap.PipelineFunctions.html#t:name_value_pair_t/0"},{"type":"type","title":"CliexMap.PipelineFunctions.numbered_line_t/0","doc":"","ref":"CliexMap.PipelineFunctions.html#t:numbered_line_t/0"},{"type":"module","title":"CliexMap.SysInterface","doc":"Implements all system dependent functions","ref":"CliexMap.SysInterface.html"},{"type":"function","title":"CliexMap.SysInterface.map_either/2","doc":"","ref":"CliexMap.SysInterface.html#map_either/2"},{"type":"function","title":"CliexMap.SysInterface.now/0","doc":"Calculates the UTC (we cannot rely on installed timezone local) timestamp in seconds","ref":"CliexMap.SysInterface.html#now/0"},{"type":"type","title":"CliexMap.SysInterface.ast/0","doc":"","ref":"CliexMap.SysInterface.html#t:ast/0"},{"type":"type","title":"CliexMap.SysInterface.binaries/0","doc":"","ref":"CliexMap.SysInterface.html#t:binaries/0"},{"type":"type","title":"CliexMap.SysInterface.binary?/0","doc":"","ref":"CliexMap.SysInterface.html#t:binary?/0"},{"type":"type","title":"CliexMap.SysInterface.color_list/0","doc":"","ref":"CliexMap.SysInterface.html#t:color_list/0"},{"type":"type","title":"CliexMap.SysInterface.either/2","doc":"","ref":"CliexMap.SysInterface.html#t:either/2"},{"type":"type","title":"CliexMap.SysInterface.line_nb_t/0","doc":"","ref":"CliexMap.SysInterface.html#t:line_nb_t/0"},{"type":"type","title":"CliexMap.SysInterface.maybe/1","doc":"","ref":"CliexMap.SysInterface.html#t:maybe/1"},{"type":"type","title":"CliexMap.SysInterface.name_value_pair_t/0","doc":"","ref":"CliexMap.SysInterface.html#t:name_value_pair_t/0"},{"type":"type","title":"CliexMap.SysInterface.numbered_line_t/0","doc":"","ref":"CliexMap.SysInterface.html#t:numbered_line_t/0"}],"content_type":"text/markdown"}